==> brian2-2.1.3-py35he980bc4_0.tar.bz2: info/test/run_test.py <==
#  tests for brian2-2.1.3-py35he980bc4_0 (this is a generated file);
print('===== testing package: brian2-2.1.3-py35he980bc4_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# Run a simple test that uses the main simulation elements and force code
# generation to use Cython
from brian2 import prefs
from brian2.tests.test_synapses import test_transmission_simple

prefs.codegen.target = 'cython'

test_transmission_simple()

#  --- run_test.py (end) ---

print('===== brian2-2.1.3-py35he980bc4_0 OK =====');
print("import: 'brian2'")
import brian2

print("import: 'brian2.codegen'")
import brian2.codegen

print("import: 'brian2.codegen.generators'")
import brian2.codegen.generators

print("import: 'brian2.codegen.runtime'")
import brian2.codegen.runtime

print("import: 'brian2.codegen.runtime.cython_rt'")
import brian2.codegen.runtime.cython_rt

print("import: 'brian2.codegen.runtime.numpy_rt'")
import brian2.codegen.runtime.numpy_rt

print("import: 'brian2.codegen.runtime.weave_rt'")
import brian2.codegen.runtime.weave_rt

print("import: 'brian2.core'")
import brian2.core

print("import: 'brian2.devices'")
import brian2.devices

print("import: 'brian2.devices.cpp_standalone'")
import brian2.devices.cpp_standalone

print("import: 'brian2.equations'")
import brian2.equations

print("import: 'brian2.groups'")
import brian2.groups

print("import: 'brian2.input'")
import brian2.input

print("import: 'brian2.memory'")
import brian2.memory

print("import: 'brian2.monitors'")
import brian2.monitors

print("import: 'brian2.parsing'")
import brian2.parsing

print("import: 'brian2.spatialneuron'")
import brian2.spatialneuron

print("import: 'brian2.sphinxext'")
import brian2.sphinxext

print("import: 'brian2.stateupdaters'")
import brian2.stateupdaters

print("import: 'brian2.synapses'")
import brian2.synapses

print("import: 'brian2.tests'")
import brian2.tests

print("import: 'brian2.tests.features'")
import brian2.tests.features

print("import: 'brian2.units'")
import brian2.units

print("import: 'brian2.utils'")
import brian2.utils

==> brian2-2.1.3.1-py35he980bc4_0.tar.bz2: info/test/run_test.py <==
#  tests for brian2-2.1.3.1-py35he980bc4_0 (this is a generated file);
print('===== testing package: brian2-2.1.3.1-py35he980bc4_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# Run a simple test that uses the main simulation elements and force code
# generation to use Cython
from brian2 import prefs
from brian2.tests.test_synapses import test_transmission_simple

prefs.codegen.target = 'cython'

test_transmission_simple()

#  --- run_test.py (end) ---

print('===== brian2-2.1.3.1-py35he980bc4_0 OK =====');
print("import: 'brian2'")
import brian2

print("import: 'brian2.codegen'")
import brian2.codegen

print("import: 'brian2.codegen.generators'")
import brian2.codegen.generators

print("import: 'brian2.codegen.runtime'")
import brian2.codegen.runtime

print("import: 'brian2.codegen.runtime.cython_rt'")
import brian2.codegen.runtime.cython_rt

print("import: 'brian2.codegen.runtime.numpy_rt'")
import brian2.codegen.runtime.numpy_rt

print("import: 'brian2.codegen.runtime.weave_rt'")
import brian2.codegen.runtime.weave_rt

print("import: 'brian2.core'")
import brian2.core

print("import: 'brian2.devices'")
import brian2.devices

print("import: 'brian2.devices.cpp_standalone'")
import brian2.devices.cpp_standalone

print("import: 'brian2.equations'")
import brian2.equations

print("import: 'brian2.groups'")
import brian2.groups

print("import: 'brian2.input'")
import brian2.input

print("import: 'brian2.memory'")
import brian2.memory

print("import: 'brian2.monitors'")
import brian2.monitors

print("import: 'brian2.parsing'")
import brian2.parsing

print("import: 'brian2.spatialneuron'")
import brian2.spatialneuron

print("import: 'brian2.sphinxext'")
import brian2.sphinxext

print("import: 'brian2.stateupdaters'")
import brian2.stateupdaters

print("import: 'brian2.synapses'")
import brian2.synapses

print("import: 'brian2.tests'")
import brian2.tests

print("import: 'brian2.tests.features'")
import brian2.tests.features

print("import: 'brian2.units'")
import brian2.units

print("import: 'brian2.utils'")
import brian2.utils
